<?php
/**
 * Example of first-factor verification of Admin password
 *
 * This example script demonstrates how integration applications can perform
 * first factor (username + password) authorization.
 *
 * Examples assumed that:
 * * The script is within the root folder of a working WHMCS deployment
 * * The username and password were securely provided from a form POST
 *
 * THE EXAMPLES IN THIS FILE ARE FOR DOCUMENTATION PURPOSES ONLY!
 * Please use the information expressed these examples in an secure manner
 * appropriate for your integration needs.
 *
 * ```php
 * $authAdmin = new WHMCS_Auth();
 * if ($authAdmin->getInfobyUsername($username)
 *     && $authAdmin->comparePassword($password)
 * ) {
 *    $isValid = true;
 * } else  {
 *    $isValid = false;
 * }
 * ```
 *
 * THE EXAMPLES IN THIS FILE ARE NOT FOR PRODUCTION USE!
 */

if (!empty($_POST)) {
    /**
     * Might want to turn on output buffering in the event that another third-party
     * integration generates stray output
     */
    //ob_start();

    /**
     * Include the WHMCS bootstrap file.
     * This ensure runtime access to WHMCS classes and libraries.
     *
     * NOTE: The bootstrap may generate output during early runtime observations,
     * like maintenance mode.
     */
    include_once dirname(__FILE__) . DIRECTORY_SEPARATOR . 'init.php';

    $result = array('valid' => 0);
    /**
     * Acquire the credentials that need to be verified
     */
    $username = (isset($_POST['user'])) ? trim($_POST['user']) : '';
    $password = (isset($_POST['password'])) ? trim($_POST['password']) : '';

    /**
     * Determine if credentials are valid
     */
    try {
        if (!$username || !$password) {
            throw new RuntimeException(
                'Cannot validate an empty username or password'
            );
        }
        /**
         * Create an object instance of the admin authentication class
         */
        $adminAuth = new WHMCS_Auth();

        /**
         * Attempt to locate the admin, automatically hydrating the object with
         * details related to the admin on success.
         *
         * getInfobyUsername(username : string, [restrictToEnabled : bool = true])
         */
        if (!$adminAuth->getInfobyUsername($username)) {
            throw new RuntimeException(
                sprintf(
                    'No enabled admin found with username "%s"',
                    $username
                )
            );
        }

        /**
         * Verify the password for the provided user
         *
         * NOTE: your integration code is intended as a drop-in replacement for
         * includes/api.php, then you should use the compareApiPassword() method.
         *
         * comparePassword(string : password)
         */
        if ($adminAuth->comparePassword($password)) {
            $result['valid'] = 1;
        }

    } catch (Exception $e) {
        /**
         * Handle any exceptional conditions
         */
    }
    /**
     * Turn off output buffering, if enabled
     */
    //ob_end_clean();

    /**
     * Perform appropriate actions
     */
    if ($result['valid']) {
        /**
         * Credentials are valid
         *
         * Perform success action here
         */

    } else {
        /**
         * Credentials are NOT valid
         *
         * Perform failure action here
         */
    }
    Header('Content-Type: application/json; charset=UTF8');
    echo json_encode($result);
    exit();
}

/**
 * Basic form to demo example code
 *
 * Modified Bootstrap 3.1.0 Snippet by http://bootsnipp.com/riliwanrabo
 * @link http://bootsnipp.com/snippets/featured/login-form-layered
 *
 * THIS IS NOT A SECURE FORM!
 * This form will not transmit over SSL, nor is there any security hardening,
 * like CSRF protection, IP restriction, IP failed-login protection, etc.
 * DO NOT USE THIS FORM IN PRODUCTION!
 */
?>
<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootswatch/3.2.0/sandstone/bootstrap.min.css">
        <title>Example: First-Factor Verification</title>
    </head>
    <body>
    <style>
        body{background: #eee }
        html,body{
            position: relative;
            height: 100%;
        }

        .login-container{
            position: relative;
            width: 300px;
            margin: 80px auto;
            padding: 20px 40px 40px;
            text-align: center;
            background: #fff;
            border: 1px solid #ccc;
        }

        #output{
            position: absolute;
            width: 300px;
            top: -75px;
            left: 0;
            color: #fff;
        }

        #output.alert-success{
            background: rgb(25, 204, 25);
        }

        #output.alert-danger{
            background: rgb(228, 105, 105);
        }


        .form-box input{
            width: 100%;
            padding: 10px;
            text-align: center;
            height:40px;
            border: 1px solid #ccc;;
            background: #fafafa;
            transition:0.2s ease-in-out;

        }

        .form-box input:focus{
            outline: 0;
            background: #eee;
        }

        .form-box input[type="text"]{
            border-radius: 5px 5px 0 0;
            text-transform: lowercase;
        }

        .form-box input[type="password"]{
            border-radius: 0 0 5px 5px;
            border-top: 0;
        }

        .form-box button.login{
            margin-top:15px;
            padding: 10px 20px;
        }

        .animated {
            -webkit-animation-duration: 1s;
            animation-duration: 1s;
            -webkit-animation-fill-mode: both;
            animation-fill-mode: both;
        }

        @-webkit-keyframes fadeInUp {
            0% {
                opacity: 0;
                -webkit-transform: translateY(20px);
                transform: translateY(20px);
            }

            100% {
                opacity: 1;
                -webkit-transform: translateY(0);
                transform: translateY(0);
            }
        }

        @keyframes fadeInUp {
            0% {
                opacity: 0;
                -webkit-transform: translateY(20px);
                -ms-transform: translateY(20px);
                transform: translateY(20px);
            }

            100% {
                opacity: 1;
                -webkit-transform: translateY(0);
                -ms-transform: translateY(0);
                transform: translateY(0);
            }
        }

        .fadeInUp {
            -webkit-animation-name: fadeInUp;
            animation-name: fadeInUp;
        }

        @-webkit-keyframes fadeOutDown {
            0% {
                opacity: 1;
                -webkit-transform: translateY(0);
            }

            100% {
                opacity: 0;
                -webkit-transform: translateY(20px);
            }
        }

        @keyframes fadeOutDown {
            0% {
                opacity: 1;
                transform: translateY(0);
            }

            100% {
                opacity: 0;
                transform: translateY(20px);
            }
        }

        .fadeOutDown {
            -webkit-animation-name: fadeOutDown;
            animation-name: fadeOutDown;
        }
    </style>

    <div class="container">
        <div class="login-container">
            <div id="output"></div>
            <div class=""></div>
            <div class="form-box">
                <form id="formVerify" name="formVerify" action="#" method="POST">
                    <fieldset>
                        <legend>Example Verification</legend>
                        <input name="user" type="text" placeholder="username" autocomplete="off" autofocus="">
                        <input name="password" type="password" placeholder="password">
                        <button class="btn btn-info btn-block login" type="submit">Verify</button>
                    </fieldset>
                </form>
            </div>
        </div>

        <script src="//ajax.googleapis.com/ajax/libs/jquery/1.10.2/jquery.min.js"></script>
        <script src="//netdna.bootstrapcdn.com/bootstrap/3.1.1/js/bootstrap.min.js"></script>
        <script type="text/javascript">
            $(function(){
                function fadeAlert(){
                    setTimeout(function(){
                        $("#output").removeClass(" fadeInUp").addClass("fadeOutDown");
                    }, 1400);
                    setTimeout(function(){
                        $("#output").html('').removeClass();
                    }, 2100);
                }

                $textfieldUser = $("input[name=user]");
                $textfieldPass = $("input[name=password]");
                $alertBox = $("#output");
                $('button[type="submit"]').click(function(e) {
                    e.preventDefault();
                    //little validation just to check username
                    if ($textfieldUser.val() == "") {
                        $alertBox.removeClass(' alert alert-success');
                        $alertBox.addClass("alert alert-danger animated fadeInUp").html("Please enter a username");
                    } else if ($textfieldPass.val() == "") {
                        $alertBox.removeClass(' alert alert-success');
                        $alertBox.addClass("alert alert-danger animated fadeInUp").html("Please enter a password");
                    } else {
                        $form = $("#formVerify");
                        $.ajax({
                            type: $form.attr('method'),
                            url: $form.attr('action'),
                            data: $form.serialize()
                        }).success(function(data) {
                            if (data.valid === 1) {
                                $alertBox.addClass("alert alert-success animated fadeInUp").html("Success!")
                                $alertBox.removeClass(' alert-danger');
                                fadeAlert();
                                $textfieldUser.val("").focus();
                                $textfieldPass.val("");
                            } else {
                                $alertBox.removeClass(' alert alert-success');
                                $alertBox.addClass("alert alert-danger animated fadeInUp").html("Sorry, those are not valid credentials");
                                fadeAlert();
                                $textfieldPass.val("").focus();
                            }

                        });
                    }
                });
            });
        </script>
    </body>
</html>

